<?php

use App\Models\Airport;
use App\Models\Client;
use App\Models\Crew;
use App\Models\Flight;
use App\Models\Plane;
use App\Models\Position;
use App\Models\Staff;
use App\Models\Tariff;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\planeController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/plane', [planeController::class, "getAll"])->name("Planes");
Route::post('/plane/create', [planeController::class, "createNew"]);
Route::get('/plane/create', function() {
    $obj = new Plane();
    return view('planeForm', array(
        "obj" => $obj,
    ));
})->name("Создание")->middleware('auth');
Route::get('/plane/edit/{instanceId}', function( $request) {
    $instanceId = $request->instanceId;
    if ($instanceId) {
        $obj = Plane::where('id', $instanceId)->first();
    }
    else {
        $obj = new Plane();
    }
    return view('planeForm', array(
        "obj" => $obj,
    ));
})->name("Редактирование")->middleware('auth');
Route::get('/plane/delete/{instanceId}', function( $instanceId) {
    Plane::where('id', $instanceId)->delete();
    return redirect('/plane');
})->name("Создание")->middleware('auth');


Route::get('/airport', [\App\Http\Controllers\AirportController::class, "getAll"])->name("Airports");
Route::post('/airport/create/', [\App\Http\Controllers\AirportController::class, "createNew"]);
Route::get('/airport/create', function() {
    $obj = new Airport();
    $planes = Plane::all();
    //dd($obj->planes);
    return view('airportForm', array(
        "obj" => $obj,
        "planes" => $planes
    ));
})->name("Создание")->middleware('auth');

Route::get('/airport/edit/{instanceId}', [\App\Http\Controllers\AirportController::class, 'editForm'])->
name("Редактирование")->middleware('auth');
Route::post('/airport/edit/{instanceId}', [\App\Http\Controllers\AirportController::class, 'editInstance'])->
name("Редактирование")->middleware('auth');
Route::get('/airport/delete/{instanceId}', function( $instanceId) {
    Airport::where('id', $instanceId)->delete();
    return redirect('/airport');
})->name("Создание")->middleware('auth');


Route::get('/client', [\App\Http\Controllers\ClientController::class, "getAll"])->name("Clients");
Route::post('/client/create/', [\App\Http\Controllers\ClientController::class, "createNew"]);
Route::get('/client/create', function() {
    $obj = new Client();
    return view('clientForm', array(
        "obj" => $obj,
    ));
})->name("Создание")->middleware('auth');

Route::get('/client/edit/{instanceId}', [\App\Http\Controllers\ClientController::class, 'editForm'])->
name("Редактирование")->middleware('auth');
Route::post('/client/edit/{instanceId}', [\App\Http\Controllers\ClientController::class, 'editInstance'])->
name("Редактирование")->middleware('auth');
Route::get('/client/delete/{instanceId}', function( $instanceId) {
    Client::where('id', $instanceId)->delete();
    return redirect('/client');
})->name("Создание")->middleware('auth');

Route::get('/crew', [\App\Http\Controllers\CrewController::class, "getAll"])->name("Crews");
Route::post('/crew/create/', [\App\Http\Controllers\CrewController::class, "createNew"]);
Route::get('/crew/create', function() {
    $obj = new Crew();
    $flights = Flight::all();
    $staffs = Staff::all();
    return view('crewForm', array(
        "obj" => $obj,
        "flights" => $flights,
        "staffs" => $staffs));
})->name("Создание")->middleware('auth');

Route::get('/crew/edit/{instanceId}', [\App\Http\Controllers\CrewController::class, 'editForm'])->
name("Редактирование")->middleware('auth');
Route::post('/crew/edit/{instanceId}', [\App\Http\Controllers\CrewController::class, 'editInstance'])->
name("Редактирование")->middleware('auth');
Route::get('/crew/delete/{instanceId}', function( $instanceId) {
    Crew::where('id', $instanceId)->delete();
    return redirect('/crew');
})->name("Создание")->middleware('auth');

Route::get('/flight', [\App\Http\Controllers\FlightController::class, "getAll"])->name("Flights");
Route::post('/flight/create/', [\App\Http\Controllers\FlightController::class, "createNew"]);
Route::get('/flight/create', function() {
    $obj = new Flight();
    $planes = Plane::all();
    $routes = \App\Models\Route::all();

    return view('flightForm', array(
        "obj" => $obj,
        "planes" => $planes,
        "routes" => $routes
    ));
})->name("Создание")->middleware('auth');

Route::get('/flight/edit/{instanceId}', [\App\Http\Controllers\FlightController::class, 'editForm'])->
name("Редактирование")->middleware('auth');
Route::post('/flight/edit/{instanceId}', [\App\Http\Controllers\FlightController::class, 'editInstance'])->
name("Редактирование")->middleware('auth');
Route::get('/flight/delete/{instanceId}', function( $instanceId) {
    Flight::where('id', $instanceId)->delete();
    return redirect('/flight');
})->name("Создание")->middleware('auth');

Route::get('/flightrecord', [\App\Http\Controllers\FlightRecordController::class, "getAll"])->name("FlightsRecord");
Route::post('/flightrecord/create/', [\App\Http\Controllers\FlightRecordController::class, "createNew"]);
Route::get('/flightrecord/create', function() {
    $obj = new \App\Models\FlightRecord();
    $flights = Flight::all();
    $clients = Client::all();
    $tariffs = Tariff::all();
    return view('flightrecordForm', array(
        "obj" => $obj,
        "flights" => $flights,
        "clients" => $clients,
        "tariffs" => $tariffs
    ));
})->name("Создание")->middleware('auth');

Route::get('/flightrecord/edit/{instanceId}', [\App\Http\Controllers\FlightRecordController::class, 'editForm'])->
name("Редактирование")->middleware('auth');
Route::post('/flightrecord/edit/{instanceId}', [\App\Http\Controllers\FlightRecordController::class, 'editInstance'])->
name("Редактирование")->middleware('auth');
Route::get('/flightrecord/delete/{instanceId}', function(\http\Env\Request $request) {
    \App\Models\FlightRecord::where('id', $request->instanceId)->delete();
    return redirect('/flightrecord');
})->name("Создание")->middleware('auth');

Route::get('/position', [\App\Http\Controllers\PositionController::class, "getAll"])->name("FlightsRecord");
Route::post('/position/create/', [\App\Http\Controllers\PositionController::class, "createNew"]);
Route::get('/position/create', function() {
    $obj = new Position();
    return view('positionForm', array(
        "obj" => $obj,
    ));
})->name("Создание")->middleware('auth');

Route::get('/position/edit/{instanceId}', [\App\Http\Controllers\PositionController::class, 'editForm'])->
name("Редактирование")->middleware('auth');
Route::post('/position/edit/{instanceId}', [\App\Http\Controllers\PositionController::class, 'editInstance'])->
name("Редактирование")->middleware('auth');
Route::get('/position/delete/{instanceId}', function( $instanceId) {
    Position::where('id', $instanceId)->delete();
    return redirect('/position');
})->name("Создание")->middleware('auth');

Route::get('/route', [\App\Http\Controllers\RouteController::class, "getAll"])->name("FlightsRecord");
Route::post('/route/create/', [\App\Http\Controllers\RouteController::class, "createNew"]);
Route::get('/route/create', function() {
    $obj = new \App\Models\Route();
    $airports = Airport::all();
    return view('routeForm', array(
        "obj" => $obj,
        "airports" => $airports
    ));
})->name("Создание")->middleware('auth');

Route::get('/route/edit/{instanceId}', [\App\Http\Controllers\RouteController::class, 'editForm'])->
name("Редактирование")->middleware('auth');
Route::post('/route/edit/{instanceId}', [\App\Http\Controllers\RouteController::class, 'editInstance'])->
name("Редактирование")->middleware('auth');
Route::get('/route/delete/{instanceId}', function( $instanceId) {
    \App\Models\Route::where('id', $instanceId)->delete();
    return redirect('/route');
})->name("Создание")->middleware('auth');


Route::get('/staff', [\App\Http\Controllers\StaffController::class, "getAll"])->name("FlightsRecord");
Route::post('/staff/create/', [\App\Http\Controllers\StaffController::class, "createNew"]);
Route::get('/staff/create', function() {
    $obj = new Staff();
    $positions = Position::all();
    return view('staffForm', array(
        "obj" => $obj,
        "positions" => $positions,
    ));
})->name("Создание")->middleware('auth');

Route::get('/staff/edit/{instanceId}', [\App\Http\Controllers\StaffController::class, 'editForm'])->
name("Редактирование")->middleware('auth');
Route::post('/staff/edit/{instanceId}', [\App\Http\Controllers\StaffController::class, 'editInstance'])->
name("Редактирование")->middleware('auth');
Route::get('/staff/delete/{instanceId}', function( $instanceId) {
    Staff::where('id', $instanceId)->delete();
    return redirect('/staff');
})->name("Создание")->middleware('auth');

Route::get('/tariff', [\App\Http\Controllers\TariffController::class, "getAll"])->name("FlightsRecord");
Route::post('/tariff/create/', [\App\Http\Controllers\TariffController::class, "createNew"]);
Route::get('/tariff/create', function() {
    $obj = new Tariff();
    return view('tariffForm', array(
        "obj" => $obj,
    ));
})->name("Создание")->middleware('auth');

Route::get('/tariff/edit/{instanceId}', [\App\Http\Controllers\TariffController::class, 'editForm'])->
name("Редактирование")->middleware('auth');
Route::post('/tariff/edit/{instanceId}', [\App\Http\Controllers\TariffController::class, 'editInstance'])->
name("Редактирование")->middleware('auth');
Route::get('/tariff/delete/{instanceId}', function( $instanceId) {
    Tariff::where('id', $instanceId)->delete();
    return redirect('/tariff');
})->name("Создание")->middleware('auth');

Route::middleware(['auth:sanctum', 'verified'])->get('/dashboard', function () {
    return view('dashboard');
})->name('dashboard');
